@@ -102,24 +102,27 @@ builder {
 ...
 
     $self->write_file('Makefile.PL', <<'...');
-use inc::Module::Install;
-all_from "lib/<% $path %>.pm";
+use ExtUtils::MakeMaker;
 
-license 'unknown';
-author  'unknown';
-
-tests 't/*.t t/*/*.t t/*/*/*.t';
-requires(
-    'Amon2'                           => '<% $amon2_version %>',
-    'Text::Xslate'                    => 0,
-    'Text::Xslate::Bridge::TT2Like'   => 0,
-    'Plack::Middleware::ReverseProxy' => 0,
-    'HTML::FillInForm::Lite'          => 0,
-    'Time::Piece'                     => 0,
+WriteMakefile(
+    NAME          => '<% $module %>',
+    AUTHOR        => 'Some Person <person@example.com>',
+    VERSION_FROM  => 'lib/<% $path %>.pm',
+    PREREQ_PM     => {
+        'Amon2'                           => '<% $amon2_version %>',
+        'Text::Xslate'                    => '1.1005',
+        'Text::Xslate::Bridge::TT2Like'   => '0.00008',
+        'Plack::Middleware::ReverseProxy' => '0.09',
+        'HTML::FillInForm::Lite'          => '1.09',
+        'Time::Piece'                     => '1.20',
+    },
+    MIN_PERL_VERSION => '5.008001',
+    (-d 'xt' and $ENV{AUTOMATED_TESTING} || $ENV{RELEASE_TESTING}) ? (
+        test => {
+            TESTS => 't/*.t xt/*.t',
+        },
+    ) : (),
 );
-recursive_author_tests('xt');
-
-WriteAll;
 ...
 
     $self->write_file('t/00_compile.t', <<'...');
